@@ -1,5 +1,5 @@
 from phidl.device_layout import Device, Group, Path, CrossSection, Port, Layer, LayerSet
 from phidl.device_layout import make_device
-from phidl.quickplotter import quickplot, quickplot2
+from phidl.quickplotter import quickplot, quickplot2, set_quickplot_options
 from phidl.device_layout import __version__, reset
 from phidl.geometry import device_lru_cache
